--AH:ScriptId=46f1897c-bb21-4fc6-85be-ee80fae8c86d;206
--select * from information_Schema.routines where routine_type='procedure'
--order by routine_name

/* Clean Old Stuff */
DROP TABLE [EventSubscriptions]
DROP TABLE [EventNotifications]
DROP TABLE [Events]

/*
drop table eventoccurencedetails
drop table eventoccurences
drop table eventtypedetails
drop table [EventTypes] 
*/

/* Events */
CREATE TABLE [EventTypes] (
  [Event_Code] CHAR(6) NOT NULL 
    CONSTRAINT [PK__EventTypes] 
    PRIMARY KEY ([Event_Code]),
  [Event_Description] VARCHAR(100) NOT NULL
)
GO

/* EventDetails */
CREATE TABLE [EventTypeDetails] (
  [Event_Code] CHAR(6) NOT NULL 
    CONSTRAINT [FK__EventTypeDetails__EventTypes]
    FOREIGN KEY ([Event_Code])
    REFERENCES [EventTypes] ([Event_Code]),
  [Detail_Name] SYSNAME NOT NULL,
  CONSTRAINT [PK__EventTypeDetails]
  PRIMARY KEY ([Event_Code],[Detail_Name]),
  [Detail_Type] SYSNAME NOT NULL
    CONSTRAINT [CK__EventTypeDetails__Detail_Type_Domain]
    CHECK ([Detail_Type] IN ('varchar','int','datetime')),
  [Detail_Sequence] INT NOT NULL
     CONSTRAINT [CK__EventTypeDetails__Detail_Sequence_Domain]
     CHECK ([Detail_Sequence] > 0),
   CONSTRAINT [UQ__EventTypeDetails__Detail_Sequence]
     UNIQUE ([Event_Code],[Detail_Sequence])
)

/* EventOccurences */
CREATE TABLE [EventOccurences] (
  [EventOccurence_Id] INT NOT NULL IDENTITY(1,1)
    CONSTRAINT [PK__EventOccurences] PRIMARY KEY  ([EventOccurence_Id]),
  [Event_Code] CHAR(6) NOT NULL 
    CONSTRAINT [FK__EventOccurences__EventTypes]
    FOREIGN KEY ([Event_Code])
    REFERENCES [EventTypes] ([Event_Code]),
  [User_Name] USERNAME NOT NULL,
  [Occurence_Date] DATETIME NOT NULL,
  [Application_Id] INT NULL 
    CONSTRAINT [FK__EventOccurences__Applications]
    FOREIGN KEY ([Application_Id])
    REFERENCES [Applications] ([Application_Id]),
)
GO


CREATE TABLE [EventOccurenceDetails] (
  [EventOccurence_Id] INT NOT NULL 
    CONSTRAINT [FK__EventOccurenceDetails__EventOccurences]
    FOREIGN KEY ([EventOccurence_Id])
    REFERENCES [EventOccurences] ([EventOccurence_Id]),
  [Event_Code] CHAR(6) NOT NULL,
  [Detail_Name] SYSNAME NOT NULL,
  CONSTRAINT [FK__EventOccurences__EventTypeDetails]
  FOREIGN KEY ([Event_Code],[Detail_Name])
  REFERENCES [EventTypeDetails] ([Event_Code],[Detail_Name]),
  [Detail_Value] SQL_VARIANT NOT NULL
)
GO

/* Data */
INSERT INTO [EventTypes] ([Event_Code],[Event_Description])
SELECT NULL [Event_Code], NULL [Event_Description] WHERE 1=0
UNION ALL SELECT 'APPDEL','Application Deleted'
UNION ALL SELECT 'APPDLS','Application Solution Deleted'
UNION ALL SELECT 'APPDLV','Application Variable Deleted'
UNION ALL SELECT 'APPMDS','Application Solution Modified'
UNION ALL SELECT 'APPMDV','Application Variable Updated'
UNION ALL SELECT 'APPMOD','Application Modified'
UNION ALL SELECT 'APPNEW','Application Created'
UNION ALL SELECT 'APPNWS','Application Solution Created'
UNION ALL SELECT 'APPNWV','Application Variable Created'
UNION ALL SELECT 'BLDAPR','Build Approval Added'
UNION ALL SELECT 'BLDCPP','Build Promotion Completed'
UNION ALL SELECT 'EXECPT','Execution Complete'
UNION ALL SELECT 'EXEINI','Execution Initiated'
UNION ALL SELECT 'BLDNEW','Build Created'
UNION ALL SELECT 'BLDPMT','Build Promoted'
UNION ALL SELECT 'BLDRJC','Build Rejected'
UNION ALL SELECT 'BLDUNA','Build Approval Removed'
UNION ALL SELECT 'BSHDEL','Build Schedule Deleted'
UNION ALL SELECT 'BSHMOD','Build Schedule Modified'
UNION ALL SELECT 'BSHNEW','Build Schedule Created'
UNION ALL SELECT 'CFGDPL','Configuration File Deployed'
UNION ALL SELECT 'CFGMDI','Configuration File Instance Updated'
UNION ALL SELECT 'CFGMOD','Configuration File Modified'
UNION ALL SELECT 'CFGNEW','Configuration File Created'
UNION ALL SELECT 'CFGNWI','Configuration File Instance Created'
UNION ALL SELECT 'CFGNWV','Configuration File Version Created'
UNION ALL SELECT 'DBSDEL','Database Change Script Provider Deleted'
UNION ALL SELECT 'DBSDLS','Database Change Script Deleted'
UNION ALL SELECT 'DBSEXC','Database Change Script Executed'
UNION ALL SELECT 'DBSMDS','Database Change Script Edit'
UNION ALL SELECT 'DBSMOD','Database Change Script Provider Modified'
UNION ALL SELECT 'DBSNEW','Database Change Script Provider Created'
UNION ALL SELECT 'DBSNWS','Database Change Script Created'
UNION ALL SELECT 'ENVDLS','Server Deleted'
UNION ALL SELECT 'ENVMDS','Server Modified'
UNION ALL SELECT 'ENVMOD','Environment Modified'
UNION ALL SELECT 'ENVNEW','Environment Created'
UNION ALL SELECT 'ENVNWS','Server Created'
UNION ALL SELECT 'EXECNL','Execution Canceled'
UNION ALL SELECT 'EXEFAL','Executions Failed'
UNION ALL SELECT 'PLNMOD','Deployment Plan Modified'
UNION ALL SELECT 'PVDDEL','Provider Deleted'
UNION ALL SELECT 'PVDMOD','Provider Modified'
UNION ALL SELECT 'PVDNEW','Provider Created'
UNION ALL SELECT 'RELCNL','Release Canceled'
UNION ALL SELECT 'RELMOD','Release Modified'
UNION ALL SELECT 'RELNEW','Release Created'
UNION ALL SELECT 'SECDLP','Security Privilege Deleted'
UNION ALL SELECT 'SECDLR','Security Role Deleted'
UNION ALL SELECT 'SECDLU','Security Named User Deleted'
UNION ALL SELECT 'SECMDR','Security Role Modified'
UNION ALL SELECT 'SECNWP','Security Privilege Created'
UNION ALL SELECT 'SECNWR','Security Role Created'
UNION ALL SELECT 'SECNWU','Security Named User Added'
UNION ALL SELECT 'SYSCFG','System Configuration Changed'
UNION ALL SELECT 'USRDLG','User Group Deleted'
UNION ALL SELECT 'USRDLU','User Deleted'
UNION ALL SELECT 'USRMDU','User Modified'
UNION ALL SELECT 'USRNWG','User Group Created'
UNION ALL SELECT 'USRNWU','User Created'
UNION ALL SELECT 'WKFDLS','Workflow Step Deleted'
UNION ALL SELECT 'WKFMDS','Workflow Step Modified'
UNION ALL SELECT 'WKFMOD','Workflow Modified'
UNION ALL SELECT 'WKFNEW','Workflow Created'
UNION ALL SELECT 'WKFNWS','Workflow Step Created'
GO

DELETE [EventTypeDetails]
INSERT INTO [EventTypeDetails] ([Event_Code],[Detail_Name],[Detail_Type],[Detail_Sequence])
SELECT NULL [Event_Code], NULL [Detail_Name], NULL [Detail_Type], NULL [Detail_Sequence] WHERE 1=0
UNION ALL SELECT 'APPDEL','Application_Name','varchar',1
UNION ALL SELECT 'APPMDS','Solution_Id','int',1
UNION ALL SELECT 'APPNWS','Solution_Id','int',1
UNION ALL SELECT 'APPDLS','Solution_Name','varchar',1
UNION ALL SELECT 'APPNWV','Variable_Name','varchar',1
UNION ALL SELECT 'APPMDV','Variable_Name','varchar',1
UNION ALL SELECT 'APPDLV','Variable_Name','varchar',1
UNION ALL SELECT 'BLDAPR','Release_Number','varchar',1
UNION ALL SELECT 'BLDCPP','Release_Number','varchar',1
UNION ALL SELECT 'EXECPT','Execution_Id','int',1
UNION ALL SELECT 'EXEINI','Execution_Id','int',1
UNION ALL SELECT 'BLDNEW','Release_Number','varchar',1
UNION ALL SELECT 'BLDPMT','Release_Number','varchar',1
UNION ALL SELECT 'BLDRJC','Release_Number','varchar',1
UNION ALL SELECT 'BLDUNA','Release_Number','varchar',1
UNION ALL SELECT 'BSHDEL','Schedule_Name','varchar',1
UNION ALL SELECT 'BSHMOD','Schedule_Id','int',1
UNION ALL SELECT 'BSHNEW','Schedule_Id','int',1
UNION ALL SELECT 'CFGDPL','ConfigurationFileDeployment_Id','int',1
UNION ALL SELECT 'CFGMDI','ConfigurationFile_Id','int',1
UNION ALL SELECT 'CFGMOD','ConfigurationFile_Id','int',1
UNION ALL SELECT 'CFGNEW','ConfigurationFile_Id','int',1
UNION ALL SELECT 'CFGNWI','ConfigurationFile_Id','int',1
UNION ALL SELECT 'CFGNWV','ConfigurationFile_Id','int',1
UNION ALL SELECT 'DBSDEL','Provider_Name','varchar',1
UNION ALL SELECT 'DBSDLS','Script_Name','varchar',1
UNION ALL SELECT 'DBSEXC','ScriptExecution_Id','int',1
UNION ALL SELECT 'DBSMDS','Script_Id','int',1
UNION ALL SELECT 'DBSMOD','Provider_Id','int',1
UNION ALL SELECT 'DBSNEW','Provider_Id','int',1
UNION ALL SELECT 'DBSNWS','Script_Id','int',1
UNION ALL SELECT 'ENVDLS','Server_Name','varchar',1
UNION ALL SELECT 'ENVMDS','Server_Id','int',1
UNION ALL SELECT 'ENVMOD','Environment_Id','int',1
UNION ALL SELECT 'ENVNEW','Environment_Id','int',1
UNION ALL SELECT 'ENVNWS','Server_Id','int',1
UNION ALL SELECT 'EXECNL','Execution_Id','int',1
UNION ALL SELECT 'PLNMOD','Plan_Id','int',1
UNION ALL SELECT 'PVDDEL','Provider_Name','varchar',1
UNION ALL SELECT 'PVDMOD','Provider_Id','int',1
UNION ALL SELECT 'PVDNEW','Provider_Id','int',1
UNION ALL SELECT 'RELCNL','Release_Number','varchar',1
UNION ALL SELECT 'RELMOD','Release_Number','varchar',1
UNION ALL SELECT 'RELNEW','Release_Number','varchar',1
UNION ALL SELECT 'SECDLP','Privilege_Id','int',1
UNION ALL SELECT 'SECDLR','Role_Name','varchar',1
UNION ALL SELECT 'SECDLU','User_Name','varchar',1
UNION ALL SELECT 'SECMDR','Role_Id','int',1
UNION ALL SELECT 'SECNWP','Privilege_Id','int',1
UNION ALL SELECT 'SECNWR','Role_Id','int',1
UNION ALL SELECT 'SECNWU','User_Name','varchar',1
UNION ALL SELECT 'SYSCFG','Key_Name','varchar',1
UNION ALL SELECT 'USRDLG','Group_Name','varchar',1
UNION ALL SELECT 'USRDLU','User_Name','varchar',1
UNION ALL SELECT 'USRMDU','User_Name','varchar',1
UNION ALL SELECT 'USRNWG','Group_Name','varchar',1
UNION ALL SELECT 'USRNWU','User_Name','varchar',1
UNION ALL SELECT 'WKFDLS','Workflow_Id','int',1
UNION ALL SELECT 'WKFMDS','Workflow_Id','int',1
UNION ALL SELECT 'WKFMOD','Workflow_Id','int',1
UNION ALL SELECT 'WKFNEW','Workflow_Id','int',1
UNION ALL SELECT 'WKFNWS','Workflow_Id','int',1

UNION ALL SELECT 'BLDAPR','Build_Number','varchar',2
UNION ALL SELECT 'BLDCPP','Build_Number','varchar',2
UNION ALL SELECT 'BLDNEW','Build_Number','varchar',2
UNION ALL SELECT 'BLDPMT','Build_Number','varchar',2
UNION ALL SELECT 'BLDRJC','Build_Number','varchar',2
UNION ALL SELECT 'BLDUNA','Build_Number','varchar',2
UNION ALL SELECT 'CFGMDI','Instance_Name','varchar',2
UNION ALL SELECT 'CFGNWI','Instance_Name','varchar',2
UNION ALL SELECT 'CFGNWV','Instance_Name','varchar',2
UNION ALL SELECT 'WKFDLS','Environment_Id','int',2
UNION ALL SELECT 'WKFMDS','Environment_Id','int',2
UNION ALL SELECT 'WKFNWS','Environment_Id','int',2

UNION ALL SELECT 'BLDAPR','Environment_Id','int',3
UNION ALL SELECT 'BLDCPP','Environment_Id','int',3
UNION ALL SELECT 'BLDPMT','Environment_Id','int',3
UNION ALL SELECT 'BLDUNA','Environment_Id','int',3
UNION ALL SELECT 'CFGNWV','Version_Number','int',3

UNION ALL SELECT 'BLDAPR','Approval_Sequence','int',4
UNION ALL SELECT 'BLDUNA','Approval_Description','varchar',4


GO