IF OBJECT_ID('[__BuildMaster_StoredProcInfo]') IS NOT NULL
	DROP TABLE [__BuildMaster_StoredProcInfo]
GO

IF OBJECT_ID('[__StoredProcInfo]') IS NOT NULL
	DROP TABLE [__StoredProcInfo]
GO

CREATE TABLE [__StoredProcInfo]
(
    [StoredProc_Name] SYSNAME,
    CONSTRAINT [PK__StoredProcInfo]
        PRIMARY KEY ([StoredProc_Name]),
    [Internal_Indicator] YNINDICATOR,
    [ReturnType_Name] VARCHAR(100) NULL,
    CONSTRAINT [CK__StoredProcInfo__ReturnType_Name_Domain]
        CHECK ([ReturnType_Name] IS NULL OR [ReturnType_Name] IN ('void', 'DataRow', 'DataTable', 'DataSet')),
    [DataTableNames_Csv] VARCHAR(255) NULL,
    [OutputPropertyNames_Csv] VARCHAR(255) NULL,
    [Description_Text] VARCHAR(MAX),
    [Remarks_Text] VARCHAR(MAX)
)
GO

IF OBJECT_ID('[__BuildMaster_AddStoredProcInfo]') IS NOT NULL
	DROP PROCEDURE [__BuildMaster_AddStoredProcInfo]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [__BuildMaster_AddStoredProcInfo]
(
	@StoredProc_Name SYSNAME,
	@Internal_Indicator YNINDICATOR,
	@ReturnType_Name VARCHAR(100),
	@DataTableNames_Csv VARCHAR(255),
	@OutputPropertyNames_Csv VARCHAR(100),
	@Description_Text VARCHAR(MAX),
	@Remarks_Text VARCHAR(MAX) = NULL
)
AS
BEGIN
	
	IF EXISTS(SELECT * FROM [__StoredProcInfo] WHERE [StoredProc_Name]=@StoredProc_Name)
		DELETE [__StoredProcInfo] WHERE [StoredProc_Name]=@StoredProc_Name

    INSERT INTO [__StoredProcInfo]
    (
         [StoredProc_Name]
        ,[Internal_Indicator]
        ,[ReturnType_Name]
        ,[DataTableNames_Csv]
        ,[OutputPropertyNames_Csv]
        ,[Description_Text]
        ,[Remarks_Text]
    )
    VALUES
    (
         @StoredProc_Name
	    ,@Internal_Indicator
	    ,@ReturnType_Name
	    ,@DataTableNames_Csv
	    ,@OutputPropertyNames_Csv
	    ,@Description_Text
	    ,@Remarks_Text
    )

END
GO

GRANT EXECUTE ON [__BuildMaster_AddStoredProcInfo] TO [BuildMasterUser_Role]
GO

IF OBJECT_ID('[__BuildMaster_GetStoredProcInfo]') IS NOT NULL
	DROP PROCEDURE [__BuildMaster_GetStoredProcInfo]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [__BuildMaster_GetStoredProcInfo]
(
	@StoredProc_Name SYSNAME = NULL
)
AS
BEGIN
    
    SET NOCOUNT ON
    
    IF @StoredProc_Name IS NULL
	    SELECT * FROM [__StoredProcInfo]
	ElSE
		SELECT * FROM [__StoredProcInfo] WHERE [StoredProc_Name] = @StoredProc_Name

END
GO

GRANT EXECUTE ON [__BuildMaster_GetStoredProcInfo] TO [BuildMasterUser_Role]
GO