EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'ConfigurationFiles_CreateConfigurationFile',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'ConfigurationFile_Id',
    /* Description_Text        */ 'Creates a configuration file in the system.'
GO

IF OBJECT_ID('[ConfigurationFiles_CreateConfigurationFile]') IS NOT NULL DROP PROCEDURE [ConfigurationFiles_CreateConfigurationFile]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ConfigurationFiles_CreateConfigurationFile]
(
	@Application_Id INT,
	@Deployable_Id INT,
	@FilePath_Text VARCHAR(500),
	@ConfigurationFile_Name NVARCHAR(100),
	@Description_Text NVARCHAR(MAX),
	@ConfigurationFile_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	INSERT INTO [ConfigurationFiles] 
	(
		[Application_Id],
		[Deployable_Id],
		[FilePath_Text],
		[Active_Indicator],
		[CreatedBy_User_Name],
		[CreatedOn_Date],
		[ModifiedBy_User_Name],
		[ModifiedOn_Date],
		[ConfigurationFile_Name],
		[Description_Text]
	)
	VALUES 
	(
		@Application_Id,
		@Deployable_Id, 
		@FilePath_Text, 
		'Y',
		dbo.Session_GetUserName(),
		GETUTCDATE(),
		dbo.Session_GetUserName(),
		GETUTCDATE(),
		NULLIF(@ConfigurationFile_Name, ''),
		NULLIF(@Description_Text, '')
	)

	SET @ConfigurationFile_Id = SCOPE_IDENTITY()
	
	EXEC [Events_RaiseEvent] 'CFGNEW', @Application_Id, @ConfigurationFile_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [ConfigurationFiles_CreateConfigurationFile] TO [BuildMasterUser_Role]
