EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Executions_CompleteLogScope',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Completes a log scope.'
GO

IF OBJECT_ID('[Executions_CompleteLogScope]') IS NOT NULL DROP PROCEDURE [Executions_CompleteLogScope]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Executions_CompleteLogScope]
(
	@Execution_Id INT,
	@Scope_Sequence INT,
	@End_Date DATETIME
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @HighestLogEntry_Level INT
	SET @HighestLogEntry_Level = (SELECT MAX([LogEntry_Level])
		                            FROM [ScopedExecutionLogEntries]
								   WHERE [Execution_Id] = @Execution_Id
								     AND [Scope_Sequence] = @Scope_Sequence)

	UPDATE [ScopedExecutionLogs]
	   SET [End_Date] = @End_Date,
	       [HighestLogEntry_Level] = @HighestLogEntry_Level
	 WHERE [Execution_Id] = @Execution_Id
	   AND [Scope_Sequence] = @Scope_Sequence

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Executions_CompleteLogScope] TO [BuildMasterUser_Role]
