EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'LegacyExecutions_BeginDeploymentPlan',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'BuildExecution_DeploymentPlan_Id',
    /* Description_Text        */ 'Initiates execution of a specific deployment plan.'
GO


IF OBJECT_ID('[LegacyExecutions_BeginDeploymentPlan]') IS NOT NULL DROP PROCEDURE [LegacyExecutions_BeginDeploymentPlan]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [LegacyExecutions_BeginDeploymentPlan]
(
	@Execution_Id INT,
	@DeploymentPlan_Id INT,
	@InitiatedBy_BuildExecution_ActionGroupAction_Id INT = NULL,
	@BuildExecution_DeploymentPlan_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @DeploymentPlan_Name VARCHAR(50)
	SELECT @DeploymentPlan_Name = [DeploymentPlan_Name]
	  FROM [DeploymentPlans]
	 WHERE [DeploymentPlan_Id] = @DeploymentPlan_Id

	INSERT INTO [BuildExecution_DeploymentPlans]
	(
		[Execution_Id],
		[Original_DeploymentPlan_Id],
		[Original_DeploymentPlan_Name]
	)
	VALUES
	(
		@Execution_Id,
		@DeploymentPlan_Id,
		@DeploymentPlan_Name
	)

	SET @BuildExecution_DeploymentPlan_Id = SCOPE_IDENTITY()
	
	IF @InitiatedBy_BuildExecution_ActionGroupAction_Id IS NOT NULL
	BEGIN

		UPDATE [BuildExecution_ActionGroupActions]
		   SET [Nested_BuildExecution_DeploymentPlan_Id] = @BuildExecution_DeploymentPlan_Id
		 WHERE [BuildExecution_ActionGroupAction_Id] = @InitiatedBy_BuildExecution_ActionGroupAction_Id

	END
	ELSE IF @DeploymentPlan_Id > 0
	BEGIN

		UPDATE [BuildExecutions]
		   SET [Initial_BuildExecution_DeploymentPlan_Id] = @BuildExecution_DeploymentPlan_Id
		 WHERE [Execution_Id] = @Execution_Id

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [LegacyExecutions_BeginDeploymentPlan] TO [BuildMasterUser_Role]
