EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'LegacyExecutions_BeginDeploymentPlanActionGroup',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Initiates execution of a specific deployment plan action group.'
GO


IF OBJECT_ID('[LegacyExecutions_BeginDeploymentPlanActionGroup]') IS NOT NULL DROP PROCEDURE [LegacyExecutions_BeginDeploymentPlanActionGroup]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [LegacyExecutions_BeginDeploymentPlanActionGroup]
(
	@BuildExecution_DeploymentPlan_Id INT,
	@DeploymentPlanActionGroup_Id INT,
	@Deployable_Id INT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION
	
		IF @DeploymentPlanActionGroup_Id IS NOT NULL
		BEGIN

			INSERT INTO [BuildExecution_DeploymentPlanActionGroups]
			(
				[BuildExecution_DeploymentPlan_Id],
				[Original_DeploymentPlanActionGroup_Sequence],
				[Original_Deployable_Name],
				[Original_Deployable_Application_Name],
				[Original_DeploymentPlanActionGroup_Id],
				[Original_DeploymentPlanActionGroup_Name]
			)
			SELECT @BuildExecution_DeploymentPlan_Id,
			       DPAG.[DeploymentPlanActionGroup_Sequence],
			       D.[Deployable_Name],
				   D_A.[Application_Name],
			       @DeploymentPlanActionGroup_Id,
			       COALESCE(DPAG.[ActionGroup_Name], AG.[ActionGroup_Name])
			  FROM [DeploymentPlanActionGroups] DPAG
			       INNER JOIN [BuildExecution_DeploymentPlans] BEDP
			               ON BEDP.[BuildExecution_DeploymentPlan_Id] = @BuildExecution_DeploymentPlan_Id
			       INNER JOIN [BuildExecutions] BE
				           ON BE.[Execution_Id] = BEDP.[Execution_Id]
				   INNER JOIN [BuildPromotions] BP
				           ON BP.[Promotion_Id] = BE.[Promotion_Id]
				   INNER JOIN [Builds] B
				           ON B.[Build_Id] = BP.[Build_Id]
				   INNER JOIN [Releases] R
				           ON R.[Release_Id] = B.[Release_Id]
					LEFT JOIN [Deployables] D
			               ON D.[Deployable_Id] = @Deployable_Id
			        LEFT JOIN [Applications] D_A
			               ON D_A.[Application_Id] = D.[Application_Id]
				          AND D_A.[Application_Id] <> R.[Application_Id]
				   INNER JOIN [ActionGroups] AG
						   ON AG.[ActionGroup_Id] = DPAG.[ActionGroup_Id]
			 WHERE [DeploymentPlanActionGroup_Id] = @DeploymentPlanActionGroup_Id

		 END
		 ELSE
		 BEGIN

			INSERT INTO [BuildExecution_DeploymentPlanActionGroups]
			(
				[BuildExecution_DeploymentPlan_Id],
				[Original_DeploymentPlanActionGroup_Sequence],
				[Original_DeploymentPlanActionGroup_Id]
			)
			VALUES
			(
				@BuildExecution_DeploymentPlan_Id,
				0,
				0
			)

		 END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [LegacyExecutions_BeginDeploymentPlanActionGroup] TO [BuildMasterUser_Role]