EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Plans_CreateOrUpdateAction',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Action_Sequence',
    /* Description_Text        */ 'Creates an action in the specified action group or updates an existing one.'
GO


IF OBJECT_ID('[Plans_CreateOrUpdateAction]') IS NOT NULL DROP PROCEDURE [Plans_CreateOrUpdateAction]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Plans_CreateOrUpdateAction]
(
	@ActionGroup_Id INT = NULL,
	@Action_Sequence INT = NULL OUT,
	@Server_Id INT = NULL,
	@Server_Variable_Name VARCHAR(50) = NULL,
	@Long_Description VARCHAR(500) = NULL,
	@ResumeNextOnFailure_Indicator YNINDICATOR = NULL,
	@Action_Configuration XML = NULL,
	@Short_Description VARCHAR(100) = NULL,
	@Active_Indicator YNINDICATOR = NULL,
	@Retry_Count INT = NULL,
	@LogFailureAsWarning_Indicator YNINDICATOR = NULL,
	@Target_Server_Id INT = NULL,
	@Target_Server_Variable_Name VARCHAR(50) = NULL,
	@ExtensionConfiguration_Id INT = NULL
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @ActionGroup_Id IS NULL
	BEGIN
		RAISERROR('ActionGroup_Id must be specified.', 16, 1)
	END

	IF (@Action_Sequence IS NULL)
	BEGIN
		SET @Action_Sequence =
			(SELECT COALESCE(MAX([Action_Sequence]), 0) + 1
		       FROM [ActionGroupActions] WHERE [ActionGroup_Id] = @ActionGroup_Id)

		INSERT INTO [ActionGroupActions]
		(
			[ActionGroup_Id],
			[Action_Sequence],
			[Server_Id],
			[Server_Variable_Name],
			[Long_Description],
			[ResumeNextOnFailure_Indicator],
			[Action_Configuration],
			[Short_Description],
			[Active_Indicator],
			[Retry_Count],
			[LogFailureAsWarning_Indicator],
			[ExtensionConfiguration_Id],
			[Target_Server_Id],
			[Target_Server_Variable_Name]
		)
		VALUES
		(
			@ActionGroup_Id,
			@Action_Sequence,
			@Server_Id,
			@Server_Variable_Name,
			@Long_Description,
			COALESCE(@ResumeNextOnFailure_Indicator, 'N'),
			@Action_Configuration,
			@Short_Description,
			COALESCE(@Active_Indicator, 'Y'),
			COALESCE(@Retry_Count, 0),
			COALESCE(@LogFailureAsWarning_Indicator, 'N'),
			@ExtensionConfiguration_Id,
			@Target_Server_Id,
			@Target_Server_Variable_Name
		)

		-- disable reexecution for anything that used the plan containing the action group
		UPDATE [BuildExecutions]
		   SET [ReexecutionState_Xml] = NULL
		 WHERE [Execution_Id] IN (SELECT BEDP.[Execution_Id]
			                        FROM [BuildExecution_DeploymentPlans] BEDP
			                             INNER JOIN [DeploymentPlanActionGroups] DPAG
			                                     ON DPAG.[DeploymentPlan_Id] = BEDP.[Original_DeploymentPlan_Id]
			                       WHERE DPAG.[ActionGroup_Id] = @ActionGroup_Id)

	END
	ELSE
	BEGIN
		DECLARE @Previous_Active_Indicator YNINDICATOR
		DECLARE @Previous_ResumeNextOnFailure_Indicator YNINDICATOR
		
		SELECT @Previous_Active_Indicator = [Active_Indicator]
		  FROM [ActionGroupActions]
		 WHERE [ActionGroup_Id] = @ActionGroup_Id
		   AND [Action_Sequence] = @Action_Sequence

		UPDATE [ActionGroupActions]
		   SET [Server_Id] = @Server_Id
		      ,[Server_Variable_Name] = @Server_Variable_Name
			  ,[Long_Description] = COALESCE(@Long_Description, [Long_Description])
		      ,[Action_Configuration] = COALESCE(@Action_Configuration, [Action_Configuration])
		      ,[ResumeNextOnFailure_Indicator] = COALESCE(@ResumeNextOnFailure_Indicator, [ResumeNextOnFailure_Indicator])
			  ,[Short_Description] = COALESCE(@Short_Description, [Short_Description])
			  ,[Active_Indicator] = COALESCE(@Active_Indicator, [Active_Indicator])
			  ,[Retry_Count] = COALESCE(@Retry_Count, [Retry_Count])
			  ,[LogFailureAsWarning_Indicator] = COALESCE(@LogFailureAsWarning_Indicator, [LogFailureAsWarning_Indicator])
			  ,[Target_Server_Id] = @Target_Server_Id
			  ,[Target_Server_Variable_Name] = @Target_Server_Variable_Name
			  ,[ExtensionConfiguration_Id] = @ExtensionConfiguration_Id
		 WHERE [ActionGroup_Id] = @ActionGroup_Id
		   AND [Action_Sequence] = @Action_Sequence
	END

	DECLARE @Plans TABLE ([DeploymentPlan_Id] INT)
	INSERT INTO @Plans
	SELECT DISTINCT([DeploymentPlan_Id])
	  FROM [DeploymentPlanActionGroups]
	 WHERE [ActionGroup_Id] = @ActionGroup_Id
 
	WHILE ((SELECT COUNT(*) FROM @Plans) > 0)
	BEGIN

		DECLARE @DeploymentPlan_Id INT
		SET @DeploymentPlan_Id = (SELECT TOP 1 [DeploymentPlan_Id] FROM @Plans)
		DELETE @Plans WHERE [DeploymentPlan_Id] = @DeploymentPlan_Id

		EXEC [Events_RaiseEvent] 'PLNMOD', NULL, @DeploymentPlan_Id

	END

	UPDATE [ActionGroups]
	   SET [ModifiedOn_Date] = GETUTCDATE(),
	       [ModifiedBy_User_Name] = dbo.Session_GetUserName()
	 WHERE [ActionGroup_Id] = @ActionGroup_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Plans_CreateOrUpdateAction] TO [BuildMasterUser_Role]
