EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Plans_CreateOrUpdateDeploymentPlan',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'DeploymentPlan_Id',
    /* Description_Text        */ 'Creates a new deployment plan or changes the name of an existing deployment plan.'
GO


IF OBJECT_ID('[Plans_CreateOrUpdateDeploymentPlan]') IS NOT NULL DROP PROCEDURE [Plans_CreateOrUpdateDeploymentPlan]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Plans_CreateOrUpdateDeploymentPlan]
(
	@DeploymentPlan_Name NVARCHAR(50),
	@AllowLocalChanges_Indicator YNINDICATOR = NULL,
    @Application_Id INT = NULL,
	@DeploymentPlan_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @DeploymentPlan_Id IS NULL
	BEGIN

		INSERT INTO [DeploymentPlans]
		(
			[DeploymentPlan_Name],
			[AllowLocalChanges_Indicator],
            [Application_Id]
		)
		VALUES
		(
			@DeploymentPlan_Name,
			COALESCE(@AllowLocalChanges_Indicator, 'N'),
            @Application_Id
		)

		SET @DeploymentPlan_Id = SCOPE_IDENTITY()

	END
	ELSE
	BEGIN

		UPDATE [DeploymentPlans]
		   SET [DeploymentPlan_Name] = @DeploymentPlan_Name,
		       [AllowLocalChanges_Indicator] = COALESCE(@AllowLocalChanges_Indicator, 'N'),
               [Application_Id] = COALESCE(@Application_Id, [Application_Id])
		 WHERE [DeploymentPlan_Id] = @DeploymentPlan_Id

	END

	EXEC [Events_RaiseEvent] 'PLNMOD', NULL, @DeploymentPlan_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Plans_CreateOrUpdateDeploymentPlan] TO [BuildMasterUser_Role]
