EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'RetentionPolicies_GetReleasesToPurge',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'Releases_Extended',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets the releases for the specified retention policy that can be purged.'
GO


IF OBJECT_ID('[RetentionPolicies_GetReleasesToPurge]') IS NOT NULL DROP PROCEDURE [RetentionPolicies_GetReleasesToPurge]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [RetentionPolicies_GetReleasesToPurge]
(
	@RetentionPolicy_Id INT
)
AS
BEGIN

	SET NOCOUNT ON

    DECLARE @ReleasesMatchingFilter_Count INT
    DECLARE @ReleasesToDelete_Count INT
	DECLARE @DeployedOnly_Indicator YNINDICATOR
    DECLARE @Retention_Count INT
    DECLARE @AlwaysRetainAfter_Date DATETIME
	DECLARE @Application_Id INT
	DECLARE @ApplicationGroup_Id INT
    DECLARE @Pipeline_Id INT
    
    SELECT @DeployedOnly_Indicator = [PurgeIn_OnlyDeployedReleases_Indicator],
           @Retention_Count = [Retention_Count],
           @Application_Id = [PurgeIn_Application_Id],
           @ApplicationGroup_Id = [PurgeIn_ApplicationGroup_Id],
           @Pipeline_Id = [PurgeIn_Pipeline_Id],
           @AlwaysRetainAfter_Date = DATEADD(DAY, -1 * [Retention_Days_Count], GETUTCDATE())
      FROM [RetentionPolicies]
     WHERE [RetentionPolicy_Id] = @RetentionPolicy_Id

    IF @ApplicationGroup_Id IS NOT NULL
	BEGIN

        IF @Retention_Count IS NOT NULL
        BEGIN        
        
            SELECT @ReleasesMatchingFilter_Count = COUNT(*) 
                          FROM [Releases_Extended] R
		            INNER JOIN [Applications] A
			                ON A.[Application_Id] = R.[Application_Id]
		                 WHERE A.[ApplicationGroup_Id] = @ApplicationGroup_Id
                           AND (@Pipeline_Id IS NULL OR R.[Pipeline_Id] = @Pipeline_Id)
		                   AND (@DeployedOnly_Indicator = 'N' OR [ReleaseStatus_Name] = 'Deployed')

            SET @ReleasesToDelete_Count = @ReleasesMatchingFilter_Count - @Retention_Count
        
            IF (@ReleasesToDelete_Count < 1)
                RETURN

            SET ROWCOUNT @ReleasesToDelete_Count

        END

		SELECT R.*
		  FROM [Releases_Extended] R
		       INNER JOIN [Applications] A
			           ON A.[Application_Id] = R.[Application_Id]
		 WHERE A.[ApplicationGroup_Id] = @ApplicationGroup_Id
           AND (@Pipeline_Id IS NULL OR R.[Pipeline_Id] = @Pipeline_Id)
		   AND (@DeployedOnly_Indicator = 'N' OR [ReleaseStatus_Name] = 'Deployed')
           AND (@AlwaysRetainAfter_Date IS NULL OR R.[CreatedOn_Date] < @AlwaysRetainAfter_Date)
		 ORDER BY [CreatedOn_Date]

	END
	ELSE
	BEGIN

        IF @Retention_Count IS NOT NULL
        BEGIN        
        
            SELECT @ReleasesMatchingFilter_Count = COUNT(*) 
                          FROM [Releases_Extended]
		                 WHERE (@Application_Id IS NULL OR [Application_Id] = @Application_Id)
                           AND (@Pipeline_Id IS NULL OR [Pipeline_Id] = @Pipeline_Id)
		                   AND (@DeployedOnly_Indicator = 'N' OR [ReleaseStatus_Name] = 'Deployed')

            SET @ReleasesToDelete_Count = @ReleasesMatchingFilter_Count - @Retention_Count
        
            IF (@ReleasesToDelete_Count < 1)
                RETURN

            SET ROWCOUNT @ReleasesToDelete_Count

        END

		SELECT *
		  FROM [Releases_Extended]
		 WHERE (@Application_Id IS NULL OR [Application_Id] = @Application_Id)
           AND (@Pipeline_Id IS NULL OR [Pipeline_Id] = @Pipeline_Id)
		   AND (@DeployedOnly_Indicator = 'N' OR [ReleaseStatus_Name] = 'Deployed')
           AND (@AlwaysRetainAfter_Date IS NULL OR [CreatedOn_Date] < @AlwaysRetainAfter_Date)
		 ORDER BY [CreatedOn_Date]

	END 

END
GO

GRANT EXECUTE ON [RetentionPolicies_GetReleasesToPurge] TO [BuildMasterUser_Role]