EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Variables_CreateOrUpdateVariable',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Variable_Id',
    /* Description_Text        */ 'Creates a new variable, or updates an existing variable with the specified ID or matching scope.'
GO

IF OBJECT_ID('[Variables_CreateOrUpdateVariable]') IS NOT NULL DROP PROCEDURE [Variables_CreateOrUpdateVariable]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Variables_CreateOrUpdateVariable]
(
	@Variable_Name VARCHAR(50),
	@ValueType_Code CHAR(1),
	@Variable_Value VARBINARY(MAX),
	@Environment_Id INT = NULL,
    @ServerRole_Id INT = NULL,
    @Server_Id INT = NULL,
    @ApplicationGroup_Id INT = NULL,
    @Application_Id INT = NULL,
    @Deployable_Id INT = NULL,
    @Sensitive_Indicator YNINDICATOR = NULL,
    @EvaluateVariables_Indicator YNINDICATOR = NULL,
	@Variable_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

    DECLARE @Existing_Variable_Id INT

    SELECT @Existing_Variable_Id = [Variable_Id] 
      FROM [Variables]
     WHERE ([Variable_Id] = @Variable_Id) 
        OR  
        (   [Variable_Name] = @Variable_Name
            AND ([Environment_Id] = @Environment_Id OR ([Environment_Id] IS NULL AND @Environment_Id IS NULL))
            AND ([ServerRole_Id] = @ServerRole_Id OR ([ServerRole_Id] IS NULL AND @ServerRole_Id IS NULL))
            AND ([Server_Id] = @Server_Id OR ([Server_Id] IS NULL AND @Server_Id IS NULL))
            AND ([ApplicationGroup_Id] = @ApplicationGroup_Id OR ([ApplicationGroup_Id] IS NULL AND @ApplicationGroup_Id IS NULL))
            AND ([Application_Id] = @Application_Id OR ([Application_Id] IS NULL AND @Application_Id IS NULL))
            AND ([Deployable_Id] = @Deployable_Id OR ([Deployable_Id] IS NULL AND @Deployable_Id IS NULL))
        )

	IF @Existing_Variable_Id IS NOT NULL
	BEGIN

		UPDATE [Variables]
		   SET [Variable_Name] = @Variable_Name,
		       [ValueType_Code] = @ValueType_Code,
		       [Variable_Value] = @Variable_Value,
		       [Environment_Id] = @Environment_Id,
               [ServerRole_Id] = @ServerRole_Id,
               [Server_Id] = @Server_Id,		       
		       [ApplicationGroup_Id] = @ApplicationGroup_Id,
               [Application_Id] = @Application_Id,
               [Deployable_Id] = @Deployable_Id,
               [Sensitive_Indicator] = @Sensitive_Indicator,
               [EvaluateVariables_Indicator] = @EvaluateVariables_Indicator
		 WHERE [Variable_Id] = @Existing_Variable_Id

         SET @Variable_Id = @Existing_Variable_Id

	END
	ELSE
	BEGIN

		INSERT INTO [Variables]
		(
			[Environment_Id],
			[ServerRole_Id],
            [Server_Id],
			[ApplicationGroup_Id],
            [Application_Id],
            [Deployable_Id],
			[Variable_Name],
			[ValueType_Code],
			[Variable_Value],
            [Sensitive_Indicator],
            [EvaluateVariables_Indicator]
		)
		VALUES
		(
			@Environment_Id,			
			@ServerRole_Id,
            @Server_Id,
			@ApplicationGroup_Id,
            @Application_Id,
            @Deployable_Id,
			@Variable_Name,
			@ValueType_Code,
			@Variable_Value,
            @Sensitive_Indicator,
            @EvaluateVariables_Indicator
		)

        SET @Variable_Id = SCOPE_IDENTITY()

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Variables_CreateOrUpdateVariable] TO [BuildMasterUser_Role]
