EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Variables_GetVariablesAccessibleFromScope',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'Variables',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets the variables that are defined in any of the specified scopes.'
GO

IF OBJECT_ID('[Variables_GetVariablesAccessibleFromScope]') IS NOT NULL DROP PROCEDURE [Variables_GetVariablesAccessibleFromScope]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Variables_GetVariablesAccessibleFromScope]
(
    @Environment_Id INT = NULL,
    @ServerRole_Id INT = NULL,
    @Server_Id INT = NULL,
    @ApplicationGroup_Id INT = NULL,
    @Application_Id INT = NULL,
    @Deployable_Id INT = NULL,
    @Variable_Name VARCHAR(50) = NULL,
    @ExpandRolesAndEnvironments_Indicator YNINDICATOR = NULL,
    @IncludeSystemVariables_Indicator YNINDICATOR = NULL
)
AS
BEGIN
    SET NOCOUNT ON;

    WITH AGA AS (
      SELECT [ApplicationGroup_Id]
        FROM dbo.ApplicationGroups_GetAncestorGroups(@ApplicationGroup_Id)
    ), ENV AS (
      SELECT [Environment_Id] = @Environment_Id
      UNION ALL
      SELECT [Environment_Id]
        FROM dbo.Environments_GetAncestorEnvironments(@Environment_Id)
       WHERE @ExpandRolesAndEnvironments_Indicator = 'Y'
         AND [Level] > 0
    ), SR AS (
      SELECT [ServerRole_Id] = @ServerRole_Id
      UNION ALL
      SELECT [ServerRole_Id]
        FROM [ServerRoleServers]
       WHERE @ExpandRolesAndEnvironments_Indicator = 'Y'
         AND [Server_Id] = @Server_Id
    )
    SELECT *
      FROM [Variables] V
     WHERE ([Variable_Name] = @Variable_Name OR @Variable_Name IS NULL)
       AND ([Environment_Id] IN (SELECT [Environment_Id] FROM ENV)
            OR [ServerRole_Id] IN (SELECT [ServerRole_Id] FROM SR)
            OR [Server_Id] = @Server_Id
            OR [ApplicationGroup_Id] IN (SELECT [ApplicationGroup_Id] FROM AGA)
            OR [Application_Id] = @Application_Id
            OR [Deployable_Id] = @Deployable_Id
            OR (@IncludeSystemVariables_Indicator = 'Y' AND [Environment_Id] IS NULL AND [ServerRole_Id] IS NULL AND [Server_Id] IS NULL AND [ApplicationGroup_Id] IS NULL AND [Application_Id] IS NULL AND [Deployable_Id] IS NULL))

END
GO

GRANT EXECUTE ON [Variables_GetVariablesAccessibleFromScope] TO [BuildMasterUser_Role]